<template>
  <div class="flex w-full flex-col gap-2 z-30 justify-center my-8 items-center text-center">
    <div
        :class="`inline-block items-center text-center bg-gray-200 text-gray-600 text-sm rounded-md py-2 px-3 w-auto min-w-150`">
      {{
        `${helpers.formatDate(date, 7)} - ${message}`
      }}
    </div>
    <div v-if="is_conversation == 1" class="flex gap-2 items-center">
      <button @click="openDialog('search')" :class="`btn btn-primary btn-sm capitalize font-normal ${generalStore.is_same_vendor == false ? '!text-white !bg-[#757575]' : ''}`" :disabled="generalStore.is_same_vendor == false">
        <svg width="14" height="14" class="mr-1" viewBox="0 0 12 12" fill="none" xmlns="http://www.w3.org/2000/svg">
          <path d="M6 1.125C3.312 1.125 1.125 3.312 1.125 6C1.125 8.688 3.312 10.875 6 10.875C8.688 10.875 10.875 8.688 10.875 6C10.875 3.312 8.688 1.125 6 1.125ZM6 1.875C8.28263 1.875 10.125 3.71738 10.125 6C10.125 8.28263 8.28263 10.125 6 10.125C3.71738 10.125 1.875 8.28263 1.875 6C1.875 3.71738 3.71738 1.875 6 1.875ZM5.625 3.75V5.625H3.75V6.375H5.625V8.25H6.375V6.375H8.25V5.625H6.375V3.75H5.625Z" fill="white"/>
        </svg>
        Conversation Label
      </button>
      <button v-if="labels.length > 0" @click="openDialog('list')"
              class="btn btn-outline btn-sm capitalize font-normal">{{labels.length}}+</button>
    </div>
  </div>
</template>
<script setup lang="ts">
import helpers from "../../utils/helpers";
import {ref} from "vue";
import {useChatListStore} from "../../stores/chat_list";
import {useGeneralStore} from "../../stores/general";
interface Props {
  isSeller?: boolean
  isLoader?: boolean
  is_forwarded?: number
  labels?: any
  is_conversation?: number
  conversation_id?: number
  date?: string
  assignee?:  {
    full_name?: string
  }
  message?: string
  id?: bigint
  wa_error_message?: string
  chatType?: string
  status?: string
  object?: any
  reactions?: any
  buttonLabel?: string|null
}
let props = withDefaults(defineProps<Props>(), {
  isSeller: false,
  isLoader: false,
  is_forwarded: 0,
  conversation_id: null,
  is_conversation: 0,
  id: null,
  date: null,
  buttonLabel: null,
  assignee: null,
  chatType: null,
  wa_error_message: null,
  status: 'sent',
  message: null,
  labels: [],
  reactions: [],
  object: {
    list: []
  },
});
const generalStore = useGeneralStore()
const general = useChatListStore()
const showConversationLabel = ref(true)

const openDialog = (type) => {
  general.conversationLabelDialog = {
    id: props?.id,
    type: type,
    isOpen: true,
    conversation_id: props?.conversation_id,
    data: props?.labels
  }
}

</script>
